@@ -24,6 +24,9 @@ Contact: yuvraaj@gmail.com
 #include "GVNumModel.h"
 #include <QDesktopServices>
 
+#define BROWSER_DIALBACK_CTX_VALUE 0x3456
+#define MIXPANEL_FLUSH_TIMEOUT (60 * 1000)
+
 IMainWindow::IMainWindow(QObject *parent)
 : QObject(parent)
 , db(this)
@@ -200,7 +203,7 @@ IMainWindow::loginCompleted()
     mEvent.distinct_id = m_user;
     mEvent.distinct_id = mEvent.distinct_id.toLower ();
     mEvent.properties["os"] = Lib::ref().getOsDetails();
-    mEvent.properties["version"] = "0.4.1868";
+    mEvent.properties["version"] = "0.4.1876";
 
     do {
         if (ATTS_SUCCESS == task->status) {
@@ -254,6 +257,7 @@ IMainWindow::loginCompleted()
             uiRequestLoginDetails();
             db.clearCookies ();
             oContacts.logout ();
+            gvApi.resetNwMgr ();
 
             mEvent.event = "Login failed";
             mEvent.properties["error"] = task->errorString;
@@ -264,6 +268,7 @@ IMainWindow::loginCompleted()
             uiRequestLoginDetails();
             db.clearCookies ();
             oContacts.logout ();
+            gvApi.resetNwMgr ();
 
             uiShowMessageBox ("Your Google Voice account is not set up. Please "
                               "access Google Voice from a desktop or laptop "
@@ -293,6 +298,7 @@ IMainWindow::loginCompleted()
             uiRequestLoginDetails();
             db.clearCookies ();
             oContacts.logout ();
+            gvApi.resetNwMgr ();
 
             mEvent.event = "Login failed";
             mEvent.properties["error"] = task->errorString;
@@ -325,7 +331,22 @@ IMainWindow::onLogoutDone()
         m_mixPanel.addEvent(m_user, "Logout");
     }
 
-    uiSetUserPass (true);
+    m_pass.clear ();
+    uiSetUserPass(true);
+    uiRequestLoginDetails();
+    oContacts.logout ();
+    gvApi.resetNwMgr ();
+
+    db.clearCookies ();
+    db.clearUserPass ();
+    db.clearContacts ();
+    db.clearInbox ();
+    db.clearSelectedPhone ();
+    db.clearCINumbers ();
+    db.deleteFilesInTempDir ();
+
+    Q_DEBUG("Logged out. Cleared out all cached info about user.");
+
     onUserLogoutDone();
     task->deleteLater();
 }//IMainWindow::onLogoutDone
@@ -386,6 +407,15 @@ IMainWindow::onUserCall(QString number)
     task->inParams["source"] = num.number;
     task->outParams["id"] = num.id;
 
+    if (num.number.contains('@')) {
+        // Warn the user that this will result in a dialback to gmail
+        uiShowMessageBox ("Browser based callback initiated.\n"
+                          "Please make sure your browser is open and ready.",
+                          (void*)BROWSER_DIALBACK_CTX_VALUE);
+        QTimer::singleShot (10 * 1000,
+                            this, SLOT(onBrowserDialbackMsgTimeout()));
+    }
+
     bool rv;
     if (num.dialBack) {
         task->inParams["sourceType"] = QString(num.chType);
@@ -401,6 +431,12 @@ IMainWindow::onUserCall(QString number)
     }
 }//IMainWindow::onUserCall
 
+void
+IMainWindow::onBrowserDialbackMsgTimeout()
+{
+    uiHideMessageBox ((void*) BROWSER_DIALBACK_CTX_VALUE);
+}//IMainWindow::onBrowserDialbackMsgTimeout
+
 void
 IMainWindow::onGvCallTaskDone()
 {
@@ -416,43 +452,40 @@ IMainWindow::onGvCallTaskDone()
     QString id = task->outParams["id"].toString();
     QString dest = task->inParams["destination"].toString();
 
-    if (ATTS_NOT_LOGGED_IN == task->status) {
-        Q_WARN(QString("Failed to initiate call to %1 using id %2 because a "
-                       "re-login is required.").arg(dest, id));
-        showStatusMessage ("Re-login required", SHOW_10SEC);
-        beginLogin (m_user, m_pass);
-
-        mixEvent.properties["Error"] = "Re-login required";
-        m_mixPanel.addEvent(mixEvent);
-        return;
-    }
-
-    if (ATTS_IN_PROGRESS == task->status) {
-        uiShowMessageBox ("A dial back call is in progress. If you did not "
-                          "want to dial back please change the dial settings "
-                          "from the qgvdial call tab");
-
-        mixEvent.properties["Error"] = "Call in progress";
-        m_mixPanel.addEvent(mixEvent);
-        return;
-    }
-
     if (ATTS_SUCCESS != task->status) {
-        Q_WARN(QString("Failed to initiate call to %1 using id %2. "
-                       "status = %3. Error reported by GV: '%4'")
-               .arg(dest, id).arg(task->status)).arg(task->errorString);
+        uiHideMessageBox ((void*) BROWSER_DIALBACK_CTX_VALUE);
 
-        QString msg;
-        if (task->errorString.isEmpty()) {
-            msg = QString("Failed to initiate call. Error = %1")
-                    .arg(task->status);
+        if (ATTS_NOT_LOGGED_IN == task->status) {
+            Q_WARN(QString("Failed to initiate call to %1 using id %2 because "
+                           "a re-login is required.").arg(dest, id));
+            showStatusMessage ("Re-login required", SHOW_10SEC);
+            beginLogin (m_user, m_pass);
+
+            mixEvent.properties["Error"] = "Re-login required";
+        } else if (ATTS_IN_PROGRESS == task->status) {
+            uiShowMessageBox ("A dial back call is in progress. If you did not "
+                              "want to dial back please change the dial "
+                              "settings from the qgvdial call tab");
+
+            mixEvent.properties["Error"] = "Call in progress";
         } else {
-            msg = QString("Google Voice error: '%1'.")
-                    .arg(task->errorString);
+            Q_WARN(QString("Failed to initiate call to %1 using id %2. "
+                           "status = %3. Error reported by GV: '%4'")
+                   .arg(dest, id).arg(task->status)).arg(task->errorString);
+
+            QString msg;
+            if (task->errorString.isEmpty()) {
+                msg = QString("Failed to initiate call. Error = %1")
+                        .arg(task->status);
+            } else {
+                msg = QString("Google Voice error: '%1'.")
+                        .arg(task->errorString);
+            }
+            showStatusMessage(msg, SHOW_10SEC);
+
+            mixEvent.properties["Error"] = msg;
         }
-        showStatusMessage(msg, SHOW_10SEC);
 
-        mixEvent.properties["Error"] = msg;
         m_mixPanel.addEvent(mixEvent);
         return;
     }
@@ -557,6 +590,8 @@ IMainWindow::onGvTextTaskDone()
         showStatusMessage ("Text sent", SHOW_3SEC);
 
         m_mixPanel.addEvent(m_user, "SMS sent");
+
+        oInbox.refreshLatestNotrash ();
     }
 }//IMainWindow::onGvTextTaskDone
 
@@ -684,5 +719,5 @@ void
 IMainWindow::onMixEventAdded()
 {
     m_mixpanelTimer.stop ();
-    m_mixpanelTimer.start (15 * 1000);
+    m_mixpanelTimer.start (MIXPANEL_FLUSH_TIMEOUT);
 }//IMainWindow::onMixEventAdded
